

package blast

class BlasteeListController {
    
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static allowedMethods = [delete:'POST', save:'POST', update:'POST']

    def list = {
        params.max = Math.min( params.max ? params.max.toInteger() : 10,  100)
        [ blasteeListInstanceList: BlasteeList.list( params ), blasteeListInstanceTotal: BlasteeList.count() ]
    }

    def show = {
        def blasteeListInstance = BlasteeList.get( params.id )

        if(!blasteeListInstance) {
            flash.message = "BlasteeList not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ blasteeListInstance : blasteeListInstance ] }
    }

    def delete = {
        def blasteeListInstance = BlasteeList.get( params.id )
        if(blasteeListInstance) {
            try {
                blasteeListInstance.delete(flush:true)
                flash.message = "BlasteeList ${params.id} deleted"
                redirect(action:list)
            }
            catch(org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "BlasteeList ${params.id} could not be deleted"
                redirect(action:show,id:params.id)
            }
        }
        else {
            flash.message = "BlasteeList not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def blasteeListInstance = BlasteeList.get( params.id )

        if(!blasteeListInstance) {
            flash.message = "BlasteeList not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ blasteeListInstance : blasteeListInstance ]
        }
    }

    def update = {
        def blasteeListInstance = BlasteeList.get( params.id )
        if(blasteeListInstance) {
            if(params.version) {
                def version = params.version.toLong()
                if(blasteeListInstance.version > version) {
                    
                    blasteeListInstance.errors.rejectValue("version", "blasteeList.optimistic.locking.failure", "Another user has updated this BlasteeList while you were editing.")
                    render(view:'edit',model:[blasteeListInstance:blasteeListInstance])
                    return
                }
            }
            blasteeListInstance.properties = params
            if(!blasteeListInstance.hasErrors() && blasteeListInstance.save()) {
                flash.message = "BlasteeList ${params.id} updated"
                redirect(action:show,id:blasteeListInstance.id)
            }
            else {
                render(view:'edit',model:[blasteeListInstance:blasteeListInstance])
            }
        }
        else {
            flash.message = "BlasteeList not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def create = {
        def blasteeListInstance = new BlasteeList()
        blasteeListInstance.blaster = Blaster.get(params.blasterId)
        return ['blasteeListInstance':blasteeListInstance]
    }

	def javaToClick2DialFlow1MachineService
	
    def save = {
        def blasteeListInstance = new BlasteeList(params)
        if(!blasteeListInstance.hasErrors() && blasteeListInstance.save()) {
			for(addr in blasteeListInstance.addressList.split(',')) {
				javaToClick2DialFlow1MachineService.initiate("sip:${addr.trim()}@claymation.com", "sip:player@claymation.com", 30, false)
			}
            flash.message = "BlasteeList ${blasteeListInstance.id} created"
            redirect(action:show,id:blasteeListInstance.id)
        }
        else {
            render(view:'create',model:[blasteeListInstance:blasteeListInstance])
        }
    }
}
