

package blast

class BlasterController {
    
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static allowedMethods = [delete:'POST', save:'POST', update:'POST']

    def list = {
        params.max = Math.min( params.max ? params.max.toInteger() : 10,  100)
        [ blasterInstanceList: Blaster.list( params ), blasterInstanceTotal: Blaster.count() ]
    }

    def show = {
        def blasterInstance = Blaster.get( params.id )

        if(!blasterInstance) {
            flash.message = "Blaster not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ blasterInstance : blasterInstance ] }
    }

    def delete = {
        def blasterInstance = Blaster.get( params.id )
        if(blasterInstance) {
            try {
                blasterInstance.delete(flush:true)
                flash.message = "Blaster ${params.id} deleted"
                redirect(action:list)
            }
            catch(org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "Blaster ${params.id} could not be deleted"
                redirect(action:show,id:params.id)
            }
        }
        else {
            flash.message = "Blaster not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def blasterInstance = Blaster.get( params.id )

        if(!blasterInstance) {
            flash.message = "Blaster not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ blasterInstance : blasterInstance ]
        }
    }

    def update = {
        def blasterInstance = Blaster.get( params.id )
        if(blasterInstance) {
            if(params.version) {
                def version = params.version.toLong()
                if(blasterInstance.version > version) {
                    
                    blasterInstance.errors.rejectValue("version", "blaster.optimistic.locking.failure", "Another user has updated this Blaster while you were editing.")
                    render(view:'edit',model:[blasterInstance:blasterInstance])
                    return
                }
            }
            blasterInstance.properties = params
            if(!blasterInstance.hasErrors() && blasterInstance.save()) {
                flash.message = "Blaster ${params.id} updated"
                redirect(action:show,id:blasterInstance.id)
            }
            else {
                render(view:'edit',model:[blasterInstance:blasterInstance])
            }
        }
        else {
            flash.message = "Blaster not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def create = {
        def blasterInstance = new Blaster()
        blasterInstance.properties = params
        return ['blasterInstance':blasterInstance]
    }

	def javaToClick2DialFlow1MachineService

    def save = {
        def blasterInstance = new Blaster(params)
        if(!blasterInstance.hasErrors() && blasterInstance.save()) {
			def address = blasterInstance.address.trim()
			javaToClick2DialFlow1MachineService.initiate("sip:${address}@claymation.com", "sip:recorder@claymation.com", 30, false)
            flash.message = "Blaster ${blasterInstance.id} created"
            // redirect(action:show,id:blasterInstance.id)
			redirect(controller:"blasteeList",action:"create", params:[blasterId:blasterInstance.id])
        }
        else {
            render(view:'create',model:[blasterInstance:blasterInstance])
        }
    }
}
